# coding=utf8
"""
A working re-implementation of the stocks module for Sopel
"""
from __future__ import unicode_literals, absolute_import, division, print_function

from .stocks import configure, get_symbol, setup, stock

__author__ = 'Rusty Bower'
__email__ = 'rusty@rustybower.com'
__version__ = '1.0.3'
